@@ -1,27 +1,30 @@
 {-# LANGUAGE NoImplicitPrelude #-}
-{-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE ViewPatterns #-}
+{-# LANGUAGE ViewPatterns      #-}
+
 module Pantry.Tree
   ( unpackTree
   , rawParseGPD
   ) where
 
-import RIO
+import           Distribution.PackageDescription ( GenericPackageDescription )
+import           Distribution.PackageDescription.Parsec
+import           Distribution.Parsec ( PWarning (..) )
+import           Pantry.Storage hiding
+                   ( Tree, TreeEntry, findOrGenerateCabalFile )
+import           Pantry.Types
+import           Path ( Abs, Dir, File, Path, toFilePath )
+import           RIO
+import qualified RIO.ByteString as B
+import           RIO.Directory
+                   ( createDirectoryIfMissing, getPermissions
+                   , setOwnerExecutable, setPermissions
+                   )
+import           RIO.FilePath ((</>), takeDirectory)
 import qualified RIO.Map as Map
 import qualified RIO.Text as T
-import qualified RIO.ByteString as B
-import Pantry.Storage hiding (Tree, TreeEntry)
-import Pantry.Types
-import RIO.FilePath ((</>), takeDirectory)
-import RIO.Directory (createDirectoryIfMissing, setPermissions, getPermissions, setOwnerExecutable)
-import Path (Path, Abs, Dir, toFilePath)
-import Distribution.Parsec (PWarning (..))
-import Distribution.PackageDescription (GenericPackageDescription)
-import Distribution.PackageDescription.Parsec
-import Path (File)
 
-unpackTree
-  :: (HasPantryConfig env, HasLogFunc env)
+unpackTree ::
+     (HasPantryConfig env, HasLogFunc env)
   => RawPackageLocationImmutable -- for exceptions
   -> Path Abs Dir -- ^ dest dir, will be created if necessary
   -> Tree
@@ -43,16 +46,16 @@ unpackTree rpli (toFilePath -> dir) (TreeMap m) = do
             perms <- getPermissions dest
             setPermissions dest $ setOwnerExecutable True perms
 
--- | A helper function that performs the basic character encoding
--- necessary.
-rawParseGPD
-  :: MonadThrow m
+-- | A helper function that performs the basic character encoding necessary.
+rawParseGPD ::
+     MonadThrow m
   => Either RawPackageLocationImmutable (Path Abs File)
   -> ByteString
   -> m ([PWarning], GenericPackageDescription)
 rawParseGPD loc bs =
-    case eres of
-      Left (mversion, errs) -> throwM $ InvalidCabalFile loc mversion (toList errs) warnings
-      Right gpkg -> return (warnings, gpkg)
-  where
-    (warnings, eres) = runParseResult $ parseGenericPackageDescription bs
+  case eres of
+    Left (mversion, errs) ->
+      throwM $ InvalidCabalFile loc mversion (toList errs) warnings
+    Right gpkg -> pure (warnings, gpkg)
+ where
+  (warnings, eres) = runParseResult $ parseGenericPackageDescription bs
